#
# spec file for package honggfuzz
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           honggfuzz
Version:        2.6
Release:        1.6
Summary:        Security-oriented fuzzer with various analysis options
License:        Apache-2.0
Group:          Development/Tools/Other
URL:            https://honggfuzz.com
Source:         https://github.com/google/honggfuzz/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  binutils-devel
BuildRequires:  libunwind-devel
BuildRequires:  libzstd-devel
BuildRequires:  zlib-devel

%description
Security-oriented fuzzer with powerful analysis options. Supports
evolutionary, feedback-driven fuzzing based on code coverage
(software and hardware).

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%make_build ARCH_LDFLAGS="-L/usr/local/include -L/usr/include -lpthread -lunwind-ptrace -lunwind-generic -lbfd -lopcodes -lrt -liberty -lz -ldl -lzstd -lsframe"

%install
install -Dpm 0755 %{name} \
  %{buildroot}%{_bindir}/%{name}

%files
%license COPYING
%doc CHANGELOG CONTRIBUTING.md README.md
%{_bindir}/%{name}

%changelog
* Tue Dec 19 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.6:
  * env NO_COLOR support
  * fix problems with linux/bfd ```init_disassemble_info```
  * Support ```--exit_on_time```
  * ```strlcat``` supported in libhfuzz/memorycmp
  * Some patches for MacOSX, sadly no support for ARM yet
  * Improvement on Android and FreeBSD targets
  * added missing ```add missing disassemble_free_target()```
- Dropped following patches as already included in upstream :
  * 0001-Always-pass-4-arguments-to-init_disassemble_info-no-.patch
  * 0002-linux-bfd-use-DIAGNOSTIC_ERROR_SWITCH-define-to-figu.patch
  * 0003-linux-bfd-cover-include-diagnostics.h-with-__has_inc.patch
* Wed Mar 15 2023 Martin Pluskal <mpluskal@suse.com>
- Fix linking with latest binutils
* Thu Aug 25 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.5
  * fixed build for Android NDK >= 23
  * fixed build for CygWin
  * improved hfuzz-cc, so it supports -x correctly
  * error returned if unknown cmd-line parameters are provided
  * support for thread CPU pinning
  * various fixes for *BSD
  * increased number of dictionary entries (to 8192)
- Add upstream changes to fix build with recent binutils:
  * 0001-Always-pass-4-arguments-to-init_disassemble_info-no-.patch
  * 0002-linux-bfd-use-DIAGNOSTIC_ERROR_SWITCH-define-to-figu.patch
  * 0003-linux-bfd-cover-include-diagnostics.h-with-__has_inc.patch
* Thu Apr 22 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.4:
  * better NetBSD support (compatiblity)
  * fixed mangle_getLen() #360
  * disabled --linux_net_ns by default, as the Linux kernel dies under heavy load of new net namespaces
  * added support for address compression in IntelPT mode
  * simplified input_skipFactor() which now yields better results (faster coverage acquisition)
  * added --save_smaller for the use with Rust fuzzing
  * fixed Android build under MacOSX
  * simplified some mangle() functions
* Wed Aug 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.3.1:
  - honggfuzz.h - split run_t into substructs
  - clang-format options in .clang-format
  - added missing mutex initializers
  - removed unncessary comparisons to 'true' and 'false'
  - improved NetBSD compatibility
  - removed unnecessary memory fences (speed ups)
  - faster searching through the binary for const 4/8-byte values
  - removed unnecessary includes with iwyu
  - libhfnetdriver - general improvements around local socket fuzzing and timeouts
  - Added 8bitcnt instrumentation - use hfuzz-cc/hfuzz-8bitcnt-(gcc|clang) for that
  - PC-guard instrumentation now uses edge counting
  - --experimental_const_feedback is now set to true by default
  - additional string instrumentation wrappers: glib, lcms
  - additional mutators: splicing, changing ascii numbers
  - additional integer comparison instrumentation (adding integers to the dynamic dictionary)
  - fixed linking with ld.lld
  - removed `sanitizer-coverage-prune-blocks` from hfuzz-cc.c
  - most mutators have now either overwrite or insert versions
  - fixed memory barriers in libhfuzz/
  - implemented skip_factor which dictates how often a given input is fuzzed
  - lowered the default timeout to 1 second
  - honggfuzz now uses microseconds, instead of milliseconds across the code
  - added some new functions to libhfcommon/files
  - enabled more aggressive inlining in hfuzz-cc/
  - fixed compilation dependency under MacOS X
- remove 0001-fix-some-m32-compilation-issues-type-casting.patch (upstream)
* Wed Mar 18 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix the i586 build:
  * 0001-fix-some-m32-compilation-issues-type-casting.patch
* Tue Mar 17 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.1:
  * string/int comparison enabled for targets built with *SAN, but
    w/o hfuzz-cc
  * Parallel work made faster by using faster ATOMIC constructs
    (check first, then update)
  * Implement --experimental_const_feedback - const string/integer
    feedback (used as an additional dictionary)
  * Sanitizer report files are "better"-deleted (i.e. based on PID
    and not TID)
  * New patches for fuzzing added (e.g. for bind-9.16.0/9.15.7)
  * Buffered output enabled in display.c
  * Some functions moved from per-arch arch.c to common subproc.c
  * Added suport for bfd/binutils-2.33
  - And more from previous releases - see provided CHANGELOG
* Thu Mar  8 2018 mpluskal@suse.com
- Clean up spec file using spec-cleaner
- Update project url
* Fri Feb 23 2018 mvetter@suse.com
- Update to version 1.5:
  * Persistent fuzzing now works with MacOS-X
  * Fixed some examples/ to make it work with MacOS-X
  * Should compile cleanly with newer MacOS-X versions
- Changes from version 1.4:
  * Socketfuzzer by @dobin
  * TCP fuzzer (HonggFuzzer NetDriver) in libhfnetdriver
  * Display: changed layout a bit
  * Better examples/ dir: Apache HTTP, ISC Bind
  * Added persistent and netdriver signatures
  * Added missing symbols for newer -fsanitize-coverage (const)
  * Changed internal structures (global vs run)
- Remove honggfuzz-binutils_2.29.patch: contained in release
* Mon Oct  2 2017 mpluskal@suse.com
- Update to version 1.1:
  * Simplified and improved hfuzz_cc compiler
  * More string instrumentation in libhfuzz
  * Android: works with Android-NDK 15 and newer only
  * Dockerfile
  * Refreshed docs
  * Linux: Faster BTS/PT due to less PMU state resets
  * Linux: tests and by-pass for the Linux' fork-when-multithreaded
    problem
  * libFuzzer/AFL style dictionaries
  * Runnable under docker/oss-fuzz
- Changes for version 1.0:
  * Multiple stability improvements for most of the supported
    architectures
  * More examples in examples/ (e.g. Linux kernel IP for BTS/PT)
  * Documentation updates
  * Added honggfuzz compiler wrapper in hfuzz_cc/
  * Reworked buffer mangling logic
- Drope reproducible.patch and gcc7.patch
- Add honggfuzz-binutils_2.29.patch to fix building with latest
  binutils
* Mon May 29 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
- Add gcc7.patch to make it build on GCC7 in Factory
* Sat Apr 29 2017 mpluskal@suse.com
- Update to version 0.9:
  * Smaller and bigger reworks:
    + Android Makefile
    + New sanitizers.c
    + Display console with scrolling logs
    + Improved libhfuzz - esp. the trace_cmp handling
    + Improved mangle.c
  * Multiple examples of persistent fuzzing: libpng, jpeg, libxml,
    apache, openssl
* Sun Feb  5 2017 jengelh@inai.de
- Update description
* Sat Jan 28 2017 mpluskal@suse.com
- Initial package for version 0.8
